@@ -1,5 +1,6 @@
 /* Linear_Expression_Unary_Minus class definition and implementation.
-   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -42,8 +43,12 @@ public class Linear_Expression_Unary_Minus
 
     //! Builds a copy of this.
     public Linear_Expression_Unary_Minus clone() {
-        return new Linear_Expression_Unary_Minus(arg.clone());
+        return new Linear_Expression_Unary_Minus(arg);
     }
 
+    private static native void initIDs();
+    static {
+        initIDs();
+    }
 }
 
