@@ -1,5 +1,6 @@
 /* Ciao Prolog extended foreign language interface: definitions.
-   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -65,7 +66,8 @@ Prolog_get_Coefficient(Prolog_term_ref t, Coefficient& n) {
 int
 Prolog_put_Coefficient(Prolog_term_ref& t, const Coefficient& n) {
   int i;
-  if (assign_r(i, n, ROUND_NOT_NEEDED) == V_EQ)
+  Result r = assign_r(i, n, ROUND_IGNORE);
+  if (!result_overflow(r))
     t = ciao_integer(i);
   else {
     std::ostringstream s;
