@@ -1,7 +1,8 @@
 % A toy, non-ground meta-interpreter for CLP(Q)
 % for testing the Parma Polyhedra Library and its Prolog interface.
 %
-% Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
+% Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
+% Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
 %
 % This file is part of the Parma Polyhedra Library (PPL).
 %
@@ -124,8 +125,10 @@ solve(_, { Constraints }, [Poly|Polys], [Poly|Polys]) :-
   % and check we do have constraints.
   constraints2list(Constraints, Constraints_List),
 
-  % Fails if `Poly' becomes empty.
-  ppl_Polyhedron_add_constraints_and_minimize(Poly, Constraints_List).
+  ppl_Polyhedron_add_constraints(Poly, Constraints_List),
+
+  % Fail if `Poly' became empty.
+  \+ ppl_Polyhedron_is_empty(Poly).
 
 % Built-ins may be added here.
 
@@ -167,7 +170,8 @@ solve(Topology, Atom, [Poly|Polys], Polys_Out) :-
   ppl_Polyhedron_add_space_dimensions_and_embed(Poly_Copy, Added_Dims),
 
   % First solve the parameter passing equations.
-  ppl_Polyhedron_add_constraints_and_minimize(Poly_Copy, Binding_Constraints),
+  ppl_Polyhedron_add_constraints(Poly_Copy, Binding_Constraints),
+  \+ ppl_Polyhedron_is_empty(Poly_Copy),
   % Then solve the body.
   solve(Topology, Body, [Poly_Copy, Poly|Polys], Polys_Soln_Out),
 
@@ -1111,7 +1115,8 @@ POSSIBILITY OF SUCH DAMAGES.\n').
 
 common_main :-
   write('\
-Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>\n\
+Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>\n\
+Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)\n\
 this program is free software, covered by the GNU General Public License,\n\
 and you are welcome to change it and/or distribute copies of it\n\
 under certain conditions.\n\
